==> nextcloud-12.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/survey_client/l10n/pl.js <==
OC.L10N.register(
    "survey_client",
    {
    "Usage survey" : "Raport użytkowania",
    "Sent on: {on}" : "Wysłano: {on}",
    "An error occurred while sending your report." : "W trakcie wysyłania Twojego raportu wystąpił błąd.",
    "App list <em>(for each app: name, version, enabled status)</em>" : "Lista aplikacji <em>(dla każdej: nazwa, wersja, stan włączenia)</em>",
    "Database environment <em>(type, version, database size)</em>" : "Środowisko bazy danych <em>(typ, wersja, rozmiar bazy)</em>",
    "Encryption information <em>(is it enabled?, what is the default module)</em>" : "Informacje dotyczące szyfrowania <em>(czy jest włączone?, jaki jest domyślny moduł?)</em>",
    "Number of shares <em>(per type and permission setting)</em>" : "Liczba udziałów <em>(z podziałem na typ oraz ustawienia dostępu)</em>",
    "PHP environment <em>(version, memory limit, max. execution time, max. file size)</em>" : "Środowisko PHP <em>(wersja, limit pamięci, maks. czas wykonania, maks. rozmiar pliku)</em>",
    "Server instance details <em>(version, memcache used, status of locking/previews/avatars)</em>" : "Szczegóły serwera <em>(wersja, użyta pamięć, status blokad/podglądów/awatarów)</em>",
    "Statistic <em>(number of: files, users, storages per type, comments and tags)</em>" : "Statystyki <em>(liczba: plików, użytkowników, typów pamięci, komentarzy oraz tagów)</em>",
    "Help improve Nextcloud" : "Pomóż w ulepszaniu Nexcloud",
    "Do you want to help us to improve Nextcloud by providing some anonymized data about your setup and usage? You can disable it at any time in the admin settings again." : "Chcesz nam pomóc ulepszyć Nextcloud przez przesłanie anonimowych statystyk dotyczących Twojej konfiguracji i użycia? W każdej chwili możesz je ponownie wyłączyć w panelu administratora.",
    "Not now" : "Nie teraz",
    "Send usage" : "Wyślij raport",
    "Never" : "Nigdy",
    "You can help improve Nextcloud by sending us some data about your current setup and usage." : "Możesz nam pomóc ulepszyć Nextcloud poprzez przesyłanie nam danych dotyczących Twojej konfiguracji i użytkowania.",
    "We take your privacy seriously. Sending data is disabled by default, and should you choose to turn it on, it will be anonymized first, and you are given the option of what things to share. Upon receiving a report, the previous one is removed. Upload a clean report to delete all data currently stored on the server" : "Twoją prywatność traktujemy poważnie. Wysyłanie danych jest domyślnie wyłączone i musisz je świadomie włączyć. Przed wysłaniem zostaną zanonimizowane, a Ty możesz wybrać które dane chcesz udostępnić. Po każdorazowym otrzymaniu nowych danych, stare raporty są kasowane. Aby usunąć swoje dane wyślij pusty raport. ",
    "Send new report now" : "Wyślij teraz nowy raport",
    "Send usage survey monthly" : "Wysyłaj raport co miesiąc",
    "Data to send" : "Dane do wysłania",
    "Last report" : "Ostatni raport",
    "Sent on: %s" : "Wysłano: %s",
    "App list <em>(for each app: name, version, is enabled?)</em>" : "Lista aplikacji <em>(dla każdej: nazwa, wersja, czy jest włączona?)</em>",
    "Server instance details <em>(version, memcache used, locking/previews/avatars enabled?)</em>" : "Szczegóły instancji serwera <em>(wersja, użyty memcache, czy są włączone blokowanie/podgląd/avatary?)</em>",
    "You can help us to improve Nextcloud be sending us some data about your current setup and usage." : "Możesz nam pomóc ulepszyć Nextcloud poprzez przesyłanie nam danych dotyczących Twojej konfiguracji i użytkowania.",
    "We take your privacy seriously. The data are anonymized and you can enable/disable it at any time, by default it is always disabled. Below you can also adjust what kind of data are send and always see the last report send to us. When the server receives a new report of your instance, all entries from previous reports are removed. In case you disable one of the settings below, you can send a new report, to delete the data, that is currently stored on the server." : "Prywatność traktujemy poważnie. Dane są anonimizowane, a ich wysyłanie można włączać/wyłączać w dowolnym momencie, domyślnie nie są wysyłane. Poniżej możesz również dostosować, jakie dane przesyłasz i zobaczyć ostatni wysłany do nas raport. Kiedy serwer otrzyma nowy raport, wszystkie poprzednie wpisy zostaną usunięte. Jeśli wyłączysz jedno z poniższych ustawień, możesz wysłać nowy raport, który usunie dane aktualnie zapisane na serwerze.",
    "You can help us to improve Nextcloud by sending us some data about your current setup and usage." : "Możesz nam pomóc ulepszyć Nextcloud poprzez przesyłanie nam danych dotyczących Twojej konfiguracji i użytkowania.",
    "We take your privacy seriously. The data is anonymized and you can enable/disable it at any time, by default it is always disabled. Below you can also adjust what kind of data is sent and always see the last report sent to us. When the server receives a new report of your instance, all entries from previous reports are removed. If you disable one of the settings below, you can send a new report, which will delete the data that is currently stored on the server." : "Prywatność traktujemy poważnie. Dane są anonimizowane, a ich wysyłanie można włączać/wyłączać w dowolnym momencie, domyślnie nie są wysyłane. Poniżej możesz również dostosować, jakie dane przesyłasz i zobaczyć ostatni wysłany do nas raport. Kiedy serwer otrzyma nowy raport, wszystkie poprzednie wpisy zostaną usunięte. Jeśli wyłączysz jedno z poniższych ustawień, możesz wysłać nowy raport, który usunie dane aktualnie zapisane na serwerze."
},
"nplurals=4; plural=(n==1 ? 0 : (n%10>=2 && n%10<=4) && (n%100<12 || n%100>14) ? 1 : n!=1 && (n%10>=0 && n%10<=1) || (n%10>=5 && n%10<=9) || (n%100>=12 && n%100<=14) ? 2 : 3);");

==> nextcloud-13.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/survey_client/l10n/pl.js <==
OC.L10N.register(
    "survey_client",
    {
    "Usage survey" : "Raport użytkowania",
    "An error occurred while sending your report." : "W trakcie wysyłania Twojego raportu wystąpił błąd.",
    "App list <em>(for each app: name, version, enabled status)</em>" : "Lista aplikacji <em>(dla każdej: nazwa, wersja, stan włączenia)</em>",
    "Database environment <em>(type, version, database size)</em>" : "Środowisko bazy danych <em>(typ, wersja, rozmiar bazy)</em>",
    "Encryption information <em>(is it enabled?, what is the default module)</em>" : "Informacje dotyczące szyfrowania <em>(czy jest włączone?, jaki jest domyślny moduł?)</em>",
    "Number of shares <em>(per type and permission setting)</em>" : "Liczba udziałów <em>(z podziałem na typ oraz ustawienia dostępu)</em>",
    "PHP environment <em>(version, memory limit, max. execution time, max. file size)</em>" : "Środowisko PHP <em>(wersja, limit pamięci, maks. czas wykonania, maks. rozmiar pliku)</em>",
    "Server instance details <em>(version, memcache used, status of locking/previews/avatars)</em>" : "Szczegóły serwera <em>(wersja, użyta pamięć, status blokad/podglądów/awatarów)</em>",
    "Statistic <em>(number of: files, users, storages per type, comments and tags)</em>" : "Statystyki <em>(liczba: plików, użytkowników, typów pamięci, komentarzy oraz tagów)</em>",
    "Help improve Nextcloud" : "Pomóż w ulepszaniu Nexcloud",
    "Do you want to help us to improve Nextcloud by providing some anonymized data about your setup and usage? You can disable it at any time in the admin settings again." : "Chcesz nam pomóc ulepszyć Nextcloud przez przesłanie anonimowych statystyk dotyczących Twojej konfiguracji i użycia? W każdej chwili możesz je ponownie wyłączyć w panelu administratora.",
    "Not now" : "Nie teraz",
    "Send usage" : "Wyślij raport",
    "Never" : "Nigdy",
    "You can help improve Nextcloud by sending us some data about your current setup and usage." : "Możesz nam pomóc ulepszyć Nextcloud poprzez przesyłanie nam danych dotyczących Twojej konfiguracji i użytkowania.",
    "We take your privacy seriously. Sending data is disabled by default, and should you choose to turn it on, it will be anonymized first, and you are given the option of what things to share. Upon receiving a report, the previous one is removed. Upload a clean report to delete all data currently stored on the server" : "Twoją prywatność traktujemy poważnie. Wysyłanie danych jest domyślnie wyłączone i musisz je świadomie włączyć. Przed wysłaniem zostaną zanonimizowane, a Ty możesz wybrać które dane chcesz udostępnić. Po każdorazowym otrzymaniu nowych danych, stare raporty są kasowane. Aby usunąć swoje dane wyślij pusty raport. ",
    "Send new report now" : "Wyślij teraz nowy raport",
    "Send usage survey monthly" : "Wysyłaj raport co miesiąc",
    "Data to send" : "Dane do wysłania",
    "Last report" : "Ostatni raport",
    "Sent on: {on}" : "Wysłano: {on}",
    "App list <em>(for each app: name, version, is enabled?)</em>" : "Lista aplikacji <em>(dla każdej: nazwa, wersja, czy jest włączona?)</em>",
    "Server instance details <em>(version, memcache used, locking/previews/avatars enabled?)</em>" : "Szczegóły instancji serwera <em>(wersja, użyty memcache, czy są włączone blokowanie/podgląd/avatary?)</em>",
    "You can help us to improve Nextcloud by sending us some data about your current setup and usage." : "Możesz nam pomóc ulepszyć Nextcloud poprzez przesyłanie nam danych dotyczących Twojej konfiguracji i użytkowania.",
    "We take your privacy seriously. The data is anonymized and you can enable/disable it at any time, by default it is always disabled. Below you can also adjust what kind of data is sent and always see the last report sent to us. When the server receives a new report of your instance, all entries from previous reports are removed. If you disable one of the settings below, you can send a new report, which will delete the data that is currently stored on the server." : "Prywatność traktujemy poważnie. Dane są anonimizowane, a ich wysyłanie można włączać/wyłączać w dowolnym momencie, domyślnie nie są wysyłane. Poniżej możesz również dostosować, jakie dane przesyłasz i zobaczyć ostatni wysłany do nas raport. Kiedy serwer otrzyma nowy raport, wszystkie poprzednie wpisy zostaną usunięte. Jeśli wyłączysz jedno z poniższych ustawień, możesz wysłać nowy raport, który usunie dane aktualnie zapisane na serwerze.",
    "Sent on: %s" : "Wysłano: %s"
},
"nplurals=4; plural=(n==1 ? 0 : (n%10>=2 && n%10<=4) && (n%100<12 || n%100>14) ? 1 : n!=1 && (n%10>=0 && n%10<=1) || (n%10>=5 && n%10<=9) || (n%100>=12 && n%100<=14) ? 2 : 3);");
